function [amp,phase,fit,names,p] =NOCtidefit_ctlwrapper(dates,hts,varargin)

%NOCtidefit_ctlwrapper: Wrapper for NOCtidefit
% to check the data gaps and select the control file
%
%This will become unnecessary if NOCtidefit gets extra checks
%Also converts matlab datenumbers to Modified Julian Date.
%
%This function is required for TIDEGAUGEQC.
%
% Joanne Williams joll@noc.ac.uk March 2019

mjd=(dates-678942);


gotCtl  = 0;
gotBB   = 0;
gotFlag = 0;
verbose = 0;
I=true(size(hts));


for j = 1:2:nargin-2
    switch lower(varargin{j})
        case 'filename'
            gotCtl = 1;
        case 'struct'
            gotCtl = 1;
        case 'force'
            gotCtl = -1;
        case 'eldot'
           
            gotBB = 1;
        case 'flag'
          
            gotFlag = 1;
        case 'verbose'
        otherwise
            error('Unknown input argument : %s',varargin{j})
    end
end


if isempty(mjd)
    amp=nan;
    phase=[];
    fit=[];
    names={};
    p=[];
    warning('Time series empty? Not attempting tidal analysis!')
    return
end



if (gotCtl == 0)
    
    
    T = max(mjd)-min(mjd);
    
    
    tint=median(diff(mjd)); %The typical time interval (in days).
    %Use median to get around problems with occasional missing data or big gaps, and this will cope with a change in interval from 5min to 15 min say.
    
    N=length(mjd(~isnan(hts(I)))); %I is the flagged data
    
    datalengthapprox=N*tint;
    if datalengthapprox<0.3*T %say!
        warning('Very gappy data, forcing to user fewer constituents') %Or else actually programme it to reduce the list.
        
        if T >= 3000&&datalengthapprox/5>3000 %Empirical! Rather strict criteria based on St Louis Senegal
            force_ctl = '18yr';
        elseif T >= 365&&datalengthapprox/5>365
            force_ctl = '1yr';
        elseif T >= 180&&datalengthapprox/5>180
            force_ctl = '1yr_nolong';
        elseif T >= 90&&datalengthapprox/5>90
            force_ctl = '6mo_nolong';
        elseif T >= 20&&datalengthapprox/5>20
            force_ctl = '1mo';
        else
            amp=nan;
            phase=[];
            fit=[];
            names={};
            p=[];
            warning('Time series appears too short. Not attempting tidal analysis!')
            return
        end
    else
        if T >= 3000 
            force_ctl = '18yr';
        elseif T >= 365
            force_ctl = '1yr';
        elseif T >= 180
            force_ctl = '1yr_nolong';
        elseif T >= 90
            force_ctl = '6mo_nolong';
        elseif T >= 20
            force_ctl = '1mo';
        else
            amp=nan;
            phase=[];
            fit=[];
            names={};
            p=[];
            warning('Time series appears too short. Not attempting tidal analysis!')
            return
        end
    end
    [amp,phase,fit,names,p] = NOCtidefit(mjd,hts,'force',force_ctl,'flag',I);
    
    
else
    [amp,phase,fit,names,p] = NOCtidefit(mjd,hts,varargin{:});
    
end

