% NMINMEANS N-minute means
%
% This function can take irregular data and will return it as data at
% PERIODF regular intervals.  
%
% [HEIGHTSF,DATESF,FLAGSF]=NMINMEANS(HEIGHTS,DATES,FLAGS,PERIODF,PERMITTEDGAP)
%
% DATES   should be a vector of Matlab datenums, it may have gaps
% HEIGHTS vector of heights same size as DATES. May contain NaN
% FLAGS   ***under development. Currently a vector the same size as HEIGHTS
%           Any data marked flags=4 is set as NaN
% PERIODF period in minutes to return DATESF. Default 5 minutes
% PERMITTEDGAP gap in minutes over which NaNs or flagged data are
% interpolated.
%
% HEIGHTSF heights returned
% DATESF vector of dates returned. 
% FLAGSF ***currently unused.
%
% Jo Williams Sep 2018 joll@noc.ac.uk


function [heightsf,datesf,flagsf]=Nminmeans(heights,dates,flags,periodf,permittedgap)

%Quick way to preserve flags:
heights(flags==4)=nan;
warning('Flags need handling!')
warning('Currently all flagged data is discarded')

%Remove nans from record
dates(isnan(heights))=[];
heights(isnan(heights))=[];


%If data were 2 or 3 min intervals, it would be better to go via 6 min to
%hourly than 5 min to hourly

%Try it this way.
%First interpolate to exact 1 min intervals (Or whatever the data interval is)
%Fill the gaps with Nans.


%Then average over N min intervals
dates=dates(:);

if nargin<4
    periodf=5; %Period to return data: eg return 5 min;
end
if nargin<5
    permittedgap=2; %maximum allowable data gap in minutes. Flagged data will by interpolated across this gap
end
periodt=median(diff(dates))*24*60; %minutes



if periodt>periodf
    %We need to be careful not to resample 15 min data onto 5 min - this should be filtered properly
    error('This code is not designed for upsampling')
elseif abs(periodt-periodf)<0.01 %min
    
    warning('data already at final frequency')
    %also We need to be careful not to time shift 5 min data that is stamped at 2.5 min
end

%Output sampling
datesf=[ceil(dates(1)*24*60/periodf):floor(dates(end)*24*60/periodf)]'*periodf/(24*60);
%datesf=rounddatemin(datesf,1);
datesfmid=datesf(1:end-1)+diff(datesf)/2; %mid-points of output sampling %1 shorter than datesf

%intermediate sampling period based on bulk of data (or 1 minute)
periodq=periodt;

%
datesq=[ceil(datesf(1)*24*60):periodq:floor(datesf(end)*24*60)]'/(24*60);
%datesq=rounddatemin(datesq,1); %This prevents there being higher frequency than 1min!
datesq=rounddatesec(datesq,1); %This prevents there being higher frequency than 1sec!
%Also add in the ???????????

hq = interp1(dates,heights,datesq);

%identify which dates are big gaps & set as nan;
% Allow datesq to be permittedgap/2 minutes away from an unflagged data point
inewdate=~ismembertol(datesq,dates,permittedgap/2/(24*60),'datascale',1);
hq(inewdate)=nan;

%allow nans to propogate to protect gaps

%The following line only works if hq is 1 minute interval
%heightsf=mean(reshape(hq(2:end),5,[]),1);

%This returns the mean of the points within half a period either side of
%the sample return date, eg from 2.5min<=d<7.5min is returned as 5min. 
heightsf=nan(size(datesf));
% for iout=2:length(datesf)-1
%     ind=(datesq>=datesfmid(iout-1)&datesq<datesfmid(iout));
%     heightsf(iout)=mean(hq(ind));
% end
%THIS GIVES THE SAME BUT IS MUCH MUCH QUICKER! The usual methods of
%convolution and cumsum are problematic because of irregular time series
%and very long data arrays.
iout=2;
htemp=0;
count=0;
for iq=1:length(datesq)
    
   if datesq(iq)<datesfmid(iout) 
       htemp=htemp+hq(iq);
       count=count+1;
   else
       heightsf(iout)=htemp/count;
  
       iout=iout+1;
       htemp=hq(iq);
          count=1;
       if iout>length(datesfmid)
           break
       end
   end
end

heightsf=heightsf(2:end-1);
datesf=datesf(2:end-1); %date label at beginning of interval??

% plot(datesq,hq)
% plot(datesf,heightsf)
% %keyboard