function chanflagprefcell=channelbetter(chanvec,dateS,dateE,dates60cell,nontidalresid60cell,chan60flagSIMcell,datescell,chanflagSIMcell)

% CHANNELBETTER = switch back on the channel that is "best" during disagreements
% 
% Returns %1=GOOD 
% 3 =PROBABLY BAD for channels that are "very dissimilar"
% to the others and consistently further from the non-tidal-residual
%
% This function is required for TIDEGAUGEQC.
%
% Joanne Williams, joll@noc.ac.uk, Oct 2018


%% Now switch back on the channel that is "best" during disagreements
% Then for the "better" channel we could recalculate the predicted tide to include
% more data. The "suspect" channels remain flagged.

%So we need to switch
% between sensors - perhaps each 5 day period select the best sensor?
% It needs to be a period long enough to avoid an oscillating sensor being
% right by coincidence, and that genuine events are retained.
% If we're switching between sensors we need to compare identical periods -
% using eg iA_31 as above? Or is that too confusing?
% Remember always that this is just to flag prefered channel(s) during
% severe disagreements. If there's only one channel, it won't be marked as
% disagreeing.

%And what if the larger ntr are correct (eg 2m surge on 1 m tide and
%gauge failure)?

%Remember they are only flagged as different if one is very different
%for at least an hour.
%chanflagprefcell  is 1 for
% "not very different to other channels"
% and "during differences, overall most similar to NTR"
%Hourly data (tagged "60") is used for this so we don't flag disgreements
%in measurement technique.
%

% With 3 channels, they might be all 3 different or there might be 2 that
% agree. If there are 2 that agree, assume they are correct. If all 3 are
% different, keep the one closest to NTR=0
%
% with 2 channels, if they disagree, keep the one closes to NTR=0
 
Nchan=length(chanvec);


dateblockS=dateS:10:dateE-10;
dateblockE=dateS+10:10:dateE;
%chanflagprefcell=chanflagSIMcell;
for ichan=chanvec
    chanflagprefcell{ichan}=ones(size(chanflagSIMcell{ichan})); %#ok<AGROW>
    chanflagprefcell{ichan}(chanflagSIMcell{ichan}~=1)=3;  %PROBABLY BAD
end

for idateblock=1:length(dateblockS)
    dbS=dateblockS(idateblock);
    dbE=dateblockE(idateblock);
    if Nchan==1
        %chanflagprefcell=chanflagSIMcell; %do nothing
        
    elseif Nchan==2
        
        datesinblock1=(dates60cell{chanvec(1)}>=dbS&dates60cell{chanvec(1)}<dbE);
        datesinblock2=(dates60cell{chanvec(2)}>=dbS&dates60cell{chanvec(2)}<dbE);
        %Look at the NTR in suspect sections (DIFF to other channels and not itself Nan)
        howbadis(1)=mean(abs(nontidalresid60cell{chanvec(1)}(~chan60flagSIMcell{chanvec(1)}&datesinblock1)),'omitnan');
        howbadis(2)=mean(abs(nontidalresid60cell{chanvec(2)}(~chan60flagSIMcell{chanvec(2)}&datesinblock2)),'omitnan');
        [~,bestchan]=min(abs(howbadis));
        
  
        chanflagprefcell{bestchan}(datescell{bestchan}>=dbS&datescell{bestchan}<dbE)=1; %GOOD
        %so that one is now switched to be kept on,
        %the other is switched off when they're different
        %Note it's important to use logicals here not ones.
        
    elseif Nchan==3
        
        datesinblock1=(dates60cell{chanvec(1)}>=dbS&dates60cell{chanvec(1)}<dbE);
        datesinblock2=(dates60cell{chanvec(2)}>=dbS&dates60cell{chanvec(2)}<dbE);
        datesinblock3=(dates60cell{chanvec(3)}>=dbS&dates60cell{chanvec(3)}<dbE);
        
        %Look at the NTR in suspect sections (DIFF to other channels and not itself Nan)
        howbadis(1)=mean(abs(nontidalresid60cell{chanvec(1)}(~chan60flagSIMcell{chanvec(1)}&datesinblock1)),'omitnan');
        howbadis(2)=mean(abs(nontidalresid60cell{chanvec(2)}(~chan60flagSIMcell{chanvec(2)}&datesinblock2)),'omitnan');
        howbadis(3)=mean(abs(nontidalresid60cell{chanvec(3)}(~chan60flagSIMcell{chanvec(3)}&datesinblock3)),'omitnan');
        
        %If say 1 & 2 are similar and 3 is different, then ~chan60flagSIM1
        %and ~chan60flagSIM2 will be empty, so howbadis(1) and howbadis(2)
        %will be 0, and we shouldn't flag 3 as pref in the next step.
        
        %nanvar will return nan for an empty vector (not suspect), so we only care about non-nans.
        %If all 3 disagree but are non-nan, mark the one closest to NTR=0 as "best".
        if all(~isnan(howbadis))
            % keyboard,
            %worstchan=max(howbadis);%eg nan 0.5 nan, the middle channel is labelled
            [~,bestchan]=min(abs(howbadis));
            chanflagprefcell{bestchan}(datescell{bestchan}>=dbS&datescell{bestchan}<dbE)=1;%GOOD
            
        end
        %It's tempting here to allow the best 2 channels to be preserved
        %rather than only the best 1. However in circumstances where 2 are
        %similar and 1 is different, this should already be done. 
        
    end
end
