function [hm,datesm]=daily2mon(h,datesd,mindays)
% DAILY2MON Convert daily data to calendar monthly means
% Assumes datesd is a datenumber
% Output dates are mid-point of month, 
% ie if first date given is 1/1/1990, output is 15/Jan/1990
% 
% mindays is the mininum number of non-nan days allowed to count that month.
% (default mindays=15)
% 
% Joanne Williams, joll@noc.ac.uk,  2018

if nargin<3
    mindays=15;
end


%Ensure input(s) are column vectors, if not output is in the same format
if isrow(h)
    returnrowheights=1; 
else 
    returnrowheights=0;
end

if isrow(datesd)
    returnrowdates=1; 
else 
    returnrowdates=0;
end

datesd=datesd(:);
h=h(:);

TT=length(datesd);

[yy,mm,~,~,~,~]=datevec(datesd);

datesm=nan(floor(TT/30),1);
hm=nan(floor(TT/30),1); %estimated size, might grow a bit.
Mtot=0;
Mdays=0;
Yprev=yy(1);
Mprev=mm(1);
Mind=0;
for t=1:TT
    if yy(t)==Yprev&&mm(t)==Mprev&&t<TT%still in the same calendar month
        if ~isnan(h(t))
        Mtot=Mtot+h(t);
        Mdays=Mdays+1;
        end
        Yprev=yy(t);
        Mprev=mm(t);
    else %started new month, so do average of previous and carry on
        Mind=Mind+1;
        if Mdays>mindays
            hm(Mind)=Mtot/Mdays;
        else
            hm(Mind)=nan;
        end
        datesm(Mind)=datenum(Yprev,Mprev,15);

        Mtot=h(t);
        Mdays=1;
        Yprev=yy(t);
        Mprev=mm(t);
    end
end


%if estimate of hm, datesm size is too big, clear it out
%Get rid of anything with a nan *DATE*
hm(isnan(datesm))=[];
datesm(isnan(datesm))=[];



if returnrowheights
     hm=hm(:)';
end

if returnrowdates
    datesm=datesm(:)';
end

