function patchbackgroundx(xon,xoff,varargin)


%PATCHBACKGROUNDX - shade chunks of background to a graph
%from xon(i) to xoff(i) etc.
%Patch arguments can be specified.
%
%
%Joanne Williams, joll@noc.ac.uk, 2018

%Note this method of setting defaults
%means that if any parameter is specified then they all have to be
%but it avoids using parse_pv_pairs.m
if isempty(varargin)
    varargin={'facecolor',0.8*[1,1,1],...
        'edgecolor',0.8*[1,1,1],...
        'facealpha',0.5,...
        'edgealpha',0.5,...
        };
end


%Get extent of axis.
xl=xlim;
yl=ylim;

%Make row vectors
xon=xon(:)';
xoff=xoff(:)';

N=length(xon);
M=length(xoff);

if M>0 %There's at least one "off"
    
    if N==0 %only patch should start from Left hand edge
        xon=xl(1);
    else
        if xoff(1)<xon(1)
            %first patch should start from Left hand edge
            xon=[xl(1),xon];
        end
    end
end
if N>0 %There's at least one "on"
    
    if M==0 %only patch should extend to right hand edge
        xoff=xl(2);
    else
        if xoff(end)<xon(end)
            %last patch should extend to right hand edge
            xoff=[xoff,xl(2)];
        end
    end
end


%update
N=length(xon);
M=length(xoff);



ylower=repmat(yl(1),1,N);
yupper=repmat(yl(2),1,N);

patch('xdata',[xon;xon;xoff;xoff],...
    'ydata', [ylower;yupper;yupper;ylower],...
    varargin{:})