function [f,v,u] = phamp0(mjdn)
%
% PHAMP0 Calculates nodal amplitude factors f, and phases (including nodal
% corrections) for the standard list of constituents at time 00:00
% on day mjdn
%
% Input: mjdn (integer) = modified julian day number        
%
% Output:
%
% f (double array length ncmax) = nodal amplitude factors
% v (double array length ncmax) = phases (degrees) including nodal corrections 
% optionally return u, nodal correction to phase
%
% from Simon Williams 2018


% calculate ecliptic mean longitudes of moon (s), sun(h), lunar perigee (p),
% lunar ascending node (en) and perihelion (p1) at 00:00 on mjdn
%
      [s,h,p,en,p1] = longfindfast(mjdn);
%
% calculate nodal amplitude factors and phase corrections at 00:00 on mjdn
%
      [u,f] =  ufsetfast(p,en);
%
% calculate mean phases at 00:00 on mjdn
%
      v = vsetfast(s,h,p,p1);
%
% sum phases
%
      v = v  + u;
end
