
%PLOTWITHGAPS Plot a gappy series as if it had nans in the gaps.
%Fill the gaps by looking for gaps longer than the normal size
%add just one nan to the beginning of each gap
%
%
% Joanne Williams joll@noc.ac.uk Jan 2019


function varargout=plotwithgaps(x,y,varargin)

%Make both column vectors
x=x(:);
y=y(:);

if length(x)~=length(y)
    error('')
end

if isempty(x) %Then it'll return an empty plot but it'll still behave as if it's plotted, which we might need for legends
    xnew=[];
    ynew=[];
else
    
    %Find size of gaps & pad with 0 to give the same size
    dx=[diff(x(:));0];
    
    
    %% Estimate the usual interval of x
    deltax=median(dx);
    
    %approximate date of first gap
    xgaps=x(dx>=2*deltax)+deltax;
    [xnew,isort]=sort([x;xgaps]);
    
    ynew=[y;nan(size(xgaps))];
    ynew=ynew(isort);
    
end

%Pass to plot function
if nargout>0
    varargout{1}=plot(xnew,ynew,varargin{:});
else
    plot(xnew,ynew,varargin{:});
end
