% SELECTDATEFORMAT - manual control of date format for x axis
% (needs extending to allow y axis)
% 
% This is useful to allow dates to be specified automatically, 
% without allowing formats we don't like, such as quarters Q1
% or ambiguous US mm/dd/yy vs British dd/mm/yy. 
% 
% Typical usage is directly into the datetick routine:
% datetick('x',selectdateformat(gca),'keeplimits')
% 
% Assumes that x is an old-style Matlab datenum.
% 
% Unnecessary if new Matlab date datatype is used. 
% 
% Joanne Williams joll@noc.ac.uk March 2019
 

function dateformat=selectdateformat(ax)

    xl=get(ax,'xlim');
    if xl(2)-xl(1)>1000 %>3 years
        dateformat='yyyy';
    elseif xl(2)-xl(1)>90 %>3 months
        dateformat='yyyy mmm';
    elseif xl(2)-xl(1)>3 %>3 days
        dateformat='mmm dd';
    elseif xl(2)-xl(1)>6/24 %>6 hours
        dateformat='mmm dd HH:MM';
    elseif xl(2)-xl(1)>5/(24*60) %>5 min
        dateformat='HH:MM';
    else 
        dateformat='HH:MM:SS';
    end
    
        